==> citrine-0.9.5.tar.gz: citrine-0.9.5/i18n/en/dictionary.h <==
#define CTR_DICT_CODEGEN_MAP_NEW                 "(Map new) "
#define CTR_DICT_CODEGEN_MAP_PUT                 "put:"
#define CTR_DICT_CODEGEN_MAP_PUT_AT              " at:"
#define CTR_DICT_CODEGEN_ARRAY_NEW               "List new "
#define CTR_DICT_CODEGEN_ARRAY_NEW_PUSH          "List ← "
#define CTR_DICT_END_OF_LINE     "."
#define CTR_DICT_NIL             "Nil"
#define CTR_DICT_BOOLEAN         "Boolean"
#define CTR_DICT_TRUE            "True"
#define CTR_DICT_FALSE           "False"
#define CTR_DICT_NUMBER          "Number"
#define CTR_DICT_STRING          "String"
#define CTR_DICT_TASK      "Code"
#define CTR_DICT_OBJECT          "Object"
#define CTR_DICT_ARRAY_OBJECT     "List"
#define CTR_DICT_MAP_OBJECT      "Map"
#define CTR_DICT_PROGRAM       "Program"
#define CTR_DICT_FILE            "File"
#define CTR_DICT_MOMENT      "Moment"
#define CTR_DICT_VAR_ICON        "☞"
#define CTR_DICT_ME_ICON         "⛏"
#define CTR_DICT_MY_ICON         "⚿"
#define CTR_DICT_BULLET          "•"
#define CTR_DICT_SYMBOL_EQUALS   "="
#define CTR_DICT_PLUS            "+"
#define CTR_DICT_MINUS   	     "-"
#define CTR_DICT_MULTIPLIER   	 "×"
#define CTR_DICT_DIVISION   	 "÷"
#define CTR_DICT_GREATER   	     ">"
#define CTR_DICT_LESS   	     "<"
#define CTR_DICT_AT_SYMBOL       "?" 
#define CTR_DICT_PEN_ICON        "✎"
#define CTR_DICT_NEW_ARRAY_AND_PUSH_SYMBOL       "←"
#define CTR_DICT_GREATER_OR_EQUAL_SYMBOL         "≥"
#define CTR_DICT_LESS_OR_EQUAL_SYMBOL            "≤"
#define CTR_DICT_UNEQUALS_SYMBOL                 "≠"
#define CTR_DICT_NEW             "new"
#define CTR_DICT_EQUALS          "equals:"
#define CTR_DICT_AND             "and:"
#define CTR_DICT_OR              "or:"
#define CTR_DICT_MODULO          "modulo:"
#define CTR_DICT_NOR             "nor:"
#define CTR_DICT_ONDO            "on:do:"
#define CTR_DICT_TYPE            "type"
#define CTR_DICT_ISNIL           "Nil?"
#define CTR_DICT_MYSELF          "myself"
#define CTR_DICT_DO              "do"
#define CTR_DICT_DONE            "done"
#define CTR_DICT_IFFALSE         "false:"
#define CTR_DICT_IFTRUE          "true:"
#define CTR_DICT_WHILE           "whilst:"
#define CTR_DICT_MESSAGEARGS     "message:arguments:"
#define CTR_DICT_MESSAGE         "message:"
#define CTR_DICT_LEARN           "learn:means:"
#define CTR_DICT_BREAK           "break"
#define CTR_DICT_CONTINUE        "continue"
#define CTR_DICT_ELSE            "else:"
#define CTR_DICT_NOT             "not"
#define CTR_DICT_TONUMBER        "number"
#define CTR_DICT_ITONUMBER       "international number"
#define CTR_DICT_TOSTRING        "string"
#define CTR_DICT_CHAR_AT_SET     "character:"
#define CTR_DICT_EITHEROR        "either:or:"
#define CTR_DICT_BY_SET       	 "by:"
#define CTR_DICT_FLOOR           "floor"
#define CTR_DICT_CEIL            "ceil"
#define CTR_DICT_ROUND           "round"
#define CTR_DICT_ABS             "absolute"
#define CTR_DICT_SQRT            "square root"
#define CTR_DICT_POWER           "power:"
#define CTR_DICT_MIN             "minimum" 
#define CTR_DICT_MAX             "maximum"
#define CTR_DICT_ODD   	         "odd?" 
#define CTR_DICT_EVEN   	     "even?"
#define CTR_DICT_POS   	         "positive?" 
#define CTR_DICT_NEG   	         "negative?" 
#define CTR_DICT_TOBOOL          "boolean" 
#define CTR_DICT_RANDOM_NUM_BETWEEN         "between:and:" 
#define CTR_DICT_LENGTH	         "length" 
#define CTR_DICT_FROM_LENGTH	 "from:length:" 
#define CTR_DICT_TRIM	         "remove surrounding spaces" 
#define CTR_DICT_AT              "at:"
#define CTR_DICT_POSITION_SET    "position:" 
#define CTR_DICT_INDEX_OF        "find:" 
#define CTR_DICT_LAST_INDEX_OF	 "last:" 
#define CTR_DICT_REPLACE_WITH	 "replace:with:" 
#define CTR_DICT_SPLIT	         "split:"
#define CTR_DICT_SKIP            "offset:" 
#define CTR_DICT_RUN             "run" 
#define CTR_DICT_APPLY_TO        "apply:" 
#define CTR_DICT_APPLY_TO_AND    "apply:and:" 
#define CTR_DICT_VALUE_SET       "set:value:" 
#define CTR_DICT_ERROR	         "error:" 
#define CTR_DICT_CATCH           "catch:" 
#define CTR_DICT_PUSH_SYMBOL     ";" 
#define CTR_DICT_SHIFT           "shift" 
#define CTR_DICT_COUNT           "count" 
#define CTR_DICT_JOIN            "join:" 
#define CTR_DICT_POP             "pop" 
#define CTR_DICT_SORT            "sort:" 
#define CTR_DICT_PUT_AT          "put:at:" 
#define CTR_DICT_MAP             "map:" 
#define CTR_DICT_EACH            "each:"
#define CTR_DICT_WRITE           "write:"
#define CTR_DICT_PATH            "path"
#define CTR_DICT_READ            "read"
#define CTR_DICT_APPEND          "append:"
#define CTR_DICT_PREPEND         "prepend:"
#define CTR_DICT_EXISTS          "exists"
#define CTR_DICT_SIZE            "size"
#define CTR_DICT_DELETE          "delete"
#define CTR_DICT_USE_SET         "use:" 
#define CTR_DICT_ARRAY            "list:"
#define CTR_DICT_END             "end"
#define CTR_DICT_ARGUMENT	     "argument:" 
#define CTR_DICT_ARGUMENT_COUNT	 "arguments" 
#define CTR_DICT_WAIT_FOR_PASSW	"ask password"
#define CTR_DICT_WAIT_FOR_INPUT	 "ask" 
#define CTR_DICT_INPUT           "input" 
#define CTR_DICT_FLUSH           "flush"
#define CTR_DICT_WAIT            "wait:" 
#define CTR_DICT_TIME	         "time" 
#define CTR_DICT_RESPOND_TO      "respond:" 
#define CTR_DICT_RESPOND_TO_AND  "respond:and:" 
#define CTR_DICT_SHELL           "shell:"
#define CTR_DICT_SWEEP           "clean memory" 
#define CTR_DICT_MEMORY_LIMIT	 "memory:"
#define CTR_DICT_MEMORY          "memory"
#define CTR_DICT_GC_MODE            "tidiness:" 
#define CTR_DICT_HASH_WITH_KEY   "hash:"
#define CTR_DICT_CHARACTERS      "characters"
#define CTR_DICT_QUALIFIER_SET         "qualify:"
#define CTR_DICT_QUALIFIER   "qualifier"
#define CTR_DICT_NEW_SET         "new:"
#define CTR_DICT_HOUR            "hour"
#define CTR_DICT_HOUR_SET        "hour:"
#define CTR_DICT_MINUTE_SET      "minute:"
#define CTR_DICT_MINUTE          "minute"
#define CTR_DICT_SECOND_SET      "second:"
#define CTR_DICT_SECOND          "second"
#define CTR_DICT_DAY             "day"
#define CTR_DICT_DAY_SET         "day:"
#define CTR_DICT_WEEK            "week"
#define CTR_DICT_WEEK_SET        "week:"
#define CTR_DICT_MONTH           "month"
#define CTR_DICT_MONTH_SET       "month:"
#define CTR_DICT_YEAR            "year"
#define CTR_DICT_RAW             "raw"
#define CTR_DICT_YEAR_SET        "year:"
#define CTR_DICT_WEEK_DAY        "weekday"
#define CTR_DICT_YEAR_DAY        "day of the year"
#define CTR_DICT_ZONE            "zone"
#define CTR_DICT_ZONE_SET        "zone:"
#define CTR_DICT_ADD_SET         "add:"
#define CTR_DICT_SUBTRACT_SET    "subtract:"
#define CTR_DICT_MULTIPLIER_SET  "multiply by:"
#define CTR_DICT_DIVIDER_SET     "divide by:"
#define CTR_DICT_LAST            "last"
#define CTR_DICT_FIRST           "first"
#define CTR_DICT_SECOND_LAST     "second last"
#define CTR_DICT_FILL_WITH       "fill:with:"
#define CTR_DICT_SPLICE          "replace:length:with:"
#define CTR_DICT_VALUES          "values"
#define CTR_DICT_ENTRIES         "entries"
#define CTR_DICT_COMPARE_SET     "compare:"
#define CTR_DICT_HAS             "has:"
#define CTR_DICT_COPY            "copy"
#define CTR_DICT_CASE_DO         "case:do:"
#define CTR_DICT_STOP            "stop"
#define CTR_DICT_ASCII_UPPER_CASE                "uppercase" 
#define CTR_DICT_ASCII_LOWER_CASE                "lowercase"
#define CTR_DICT_CONTAINS                        "contains:"
#define CTR_DICT_APPLY_TO_AND_AND                "apply:and:and:"
#define CTR_DICT_ENVIRONMENT_VARIABLE            "setting:"
#define CTR_DICT_SET_ENVIRONMENT_VARIABLE        "setting:value:" 
#define CTR_DICT_RESPOND_TO_AND_AND              "respond:and:and:"
#define CTR_DICT_RESPOND_TO_AND_AND_AND          "respond:and:and:and:"
#define CTR_DICT_CURRENT_TASK                      "this code block"
#define CTR_DICT_NUM_DEC_SEP                     "."
#define CTR_DICT_NUM_THO_SEP                     ","
#define CTR_DICT_QUOT_OPEN                       "‘"
#define CTR_DICT_QUOT_CLOSE                      "’"
#define CTR_DICT_MESSAGE_CHAIN                   ","
#define CTR_DICT_ASSIGN                          "≔"
#define CTR_DICT_PAREN_OPEN                      "("
#define CTR_DICT_PAREN_CLOSE                     ")"
#define CTR_DICT_BLOCK_START                     "{"
#define CTR_DICT_BLOCK_END                       "}"
#define CTR_DICT_PARAMETER_PREFIX                ":"
#define CTR_DICT_RETURN                          "↲"
#define CTR_DICT_CODE                            "code"
#define CTR_DICT_PROCEDURE                       "procedure"
#define CTR_DICT_TOOBJECT        "object"
#define CTR_DICT_PATH_OBJECT "Path"
#define CTR_DICT_CMD_OBJECT  "Command"
#define CTR_DICT_RECURSIVE "recursive"

==> citrine-0.9.6.tar.gz: citrine-0.9.6/i18n/en/dictionary.h <==
#define CTR_DICT_CODEGEN_MAP_NEW                 "(List new) "
#define CTR_DICT_CODEGEN_MAP_PUT                 "put:"
#define CTR_DICT_CODEGEN_MAP_PUT_AT              " at:"
#define CTR_DICT_CODEGEN_ARRAY_NEW               "Sequence new "
#define CTR_DICT_CODEGEN_ARRAY_NEW_PUSH          "Sequence ← "
#define CTR_DICT_END_OF_LINE     "."
#define CTR_DICT_NIL             "None"
#define CTR_DICT_BOOLEAN         "Decision"
#define CTR_DICT_TRUE            "Yes"
#define CTR_DICT_FALSE           "No"
#define CTR_DICT_NUMBER          "Number"
#define CTR_DICT_STRING          "Text"
#define CTR_DICT_TASK            "Task"
#define CTR_DICT_OBJECT          "Object"
#define CTR_DICT_ARRAY_OBJECT    "Sequence"
#define CTR_DICT_MAP_OBJECT      "List"
#define CTR_DICT_PROGRAM         "Program"
#define CTR_DICT_FILE            "File"
#define CTR_DICT_MOMENT          "Moment"
#define CTR_DICT_VAR_ICON        "☞"
#define CTR_DICT_ME_ICON         "⛏"
#define CTR_DICT_MY_ICON         "⚿"
#define CTR_DICT_BULLET          "•"
#define CTR_DICT_SYMBOL_EQUALS   "="
#define CTR_DICT_PLUS            "+"
#define CTR_DICT_MINUS   	     "-"
#define CTR_DICT_MULTIPLIER   	 "×"
#define CTR_DICT_DIVISION   	 "÷"
#define CTR_DICT_GREATER   	     ">"
#define CTR_DICT_LESS   	     "<"
#define CTR_DICT_AT_SYMBOL       "?" 
#define CTR_DICT_PEN_ICON        "✎"
#define CTR_DICT_NEW_ARRAY_AND_PUSH_SYMBOL       "←"
#define CTR_DICT_GREATER_OR_EQUAL_SYMBOL         "≥"
#define CTR_DICT_LESS_OR_EQUAL_SYMBOL            "≤"
#define CTR_DICT_UNEQUALS_SYMBOL                 "≠"
#define CTR_DICT_NEW             "new"
#define CTR_DICT_EQUALS          "equals:"
#define CTR_DICT_AND             "and:"
#define CTR_DICT_OR              "or:"
#define CTR_DICT_MODULO          "modulo:"
#define CTR_DICT_NOR             "nor:"
#define CTR_DICT_ONDO            "on:do:"
#define CTR_DICT_TYPE            "type"
#define CTR_DICT_ISNIL           "None?"
#define CTR_DICT_MYSELF          "myself"
#define CTR_DICT_DO              "do"
#define CTR_DICT_DONE            "done"
#define CTR_DICT_IFFALSE         "no:"
#define CTR_DICT_IFTRUE          "yes:"
#define CTR_DICT_WHILE           "whilst:"
#define CTR_DICT_MESSAGEARGS     "message:arguments:"
#define CTR_DICT_MESSAGE         "message:"
#define CTR_DICT_LEARN           "learn:means:"
#define CTR_DICT_BREAK           "abort"
#define CTR_DICT_CONTINUE        "continue"
#define CTR_DICT_ELSE            "else:"
#define CTR_DICT_NOT             "not"
#define CTR_DICT_TONUMBER        "number"
#define CTR_DICT_ITONUMBER       "international number"
#define CTR_DICT_TOSTRING        "text"
#define CTR_DICT_CHAR_AT_SET     "character:"
#define CTR_DICT_EITHEROR        "either:or:"
#define CTR_DICT_BY_SET       	 "by:"
#define CTR_DICT_FLOOR           "floor"
#define CTR_DICT_CEIL            "ceil"
#define CTR_DICT_ROUND           "round"
#define CTR_DICT_ABS             "absolute"
#define CTR_DICT_SQRT            "square root"
#define CTR_DICT_POWER           "power:"
#define CTR_DICT_MIN             "minimum" 
#define CTR_DICT_MAX             "maximum"
#define CTR_DICT_ODD   	         "odd?" 
#define CTR_DICT_EVEN   	     "even?"
#define CTR_DICT_POS   	         "positive?" 
#define CTR_DICT_NEG   	         "negative?" 
#define CTR_DICT_TOBOOL          "decision" 
#define CTR_DICT_RANDOM_NUM_BETWEEN         "between:and:" 
#define CTR_DICT_LENGTH	         "length" 
#define CTR_DICT_FROM_LENGTH	 "from:length:" 
#define CTR_DICT_TRIM	         "unspace" 
#define CTR_DICT_AT              "at:"
#define CTR_DICT_POSITION_SET    "position:" 
#define CTR_DICT_INDEX_OF        "find:" 
#define CTR_DICT_LAST_INDEX_OF	 "last:" 
#define CTR_DICT_REPLACE_WITH	 "replace:with:" 
#define CTR_DICT_SPLIT	         "split:"
#define CTR_DICT_SKIP            "offset:" 
#define CTR_DICT_RUN             "start" 
#define CTR_DICT_APPLY_TO        "apply:" 
#define CTR_DICT_APPLY_TO_AND    "apply:and:" 
#define CTR_DICT_VALUE_SET       "set:value:" 
#define CTR_DICT_ERROR	         "error:" 
#define CTR_DICT_CATCH           "except:" 
#define CTR_DICT_PUSH_SYMBOL     ";" 
#define CTR_DICT_SHIFT           "shift" 
#define CTR_DICT_COUNT           "count" 
#define CTR_DICT_JOIN            "combine:" 
#define CTR_DICT_POP             "pop" 
#define CTR_DICT_SORT            "sort:" 
#define CTR_DICT_PUT_AT          "put:at:" 
#define CTR_DICT_MAP             "list:" 
#define CTR_DICT_EACH            "each:"
#define CTR_DICT_WRITE           "write:"
#define CTR_DICT_PATH            "path"
#define CTR_DICT_READ            "read"
#define CTR_DICT_APPEND          "append:"
#define CTR_DICT_PREPEND         "prepend:"
#define CTR_DICT_EXISTS          "exists"
#define CTR_DICT_SIZE            "size"
#define CTR_DICT_DELETE          "delete"
#define CTR_DICT_USE_SET         "use:" 
#define CTR_DICT_ARRAY            "sequence:"
#define CTR_DICT_END             "end"
#define CTR_DICT_ARGUMENT	     "argument:" 
#define CTR_DICT_ARGUMENT_COUNT	 "arguments" 
#define CTR_DICT_WAIT_FOR_PASSW	"ask password"
#define CTR_DICT_WAIT_FOR_INPUT	 "ask" 
#define CTR_DICT_INPUT           "input" 
#define CTR_DICT_FLUSH           "flush"
#define CTR_DICT_WAIT            "wait:" 
#define CTR_DICT_TIME	         "time" 
#define CTR_DICT_RESPOND_TO      "respond:" 
#define CTR_DICT_RESPOND_TO_AND  "respond:and:" 
#define CTR_DICT_SHELL           "os:"
#define CTR_DICT_SWEEP           "clean up" 
#define CTR_DICT_MEMORY_LIMIT	 "memory:"
#define CTR_DICT_MEMORY          "memory"
#define CTR_DICT_GC_MODE         "memory management:" 
#define CTR_DICT_HASH_WITH_KEY   "hash:"
#define CTR_DICT_CHARACTERS      "characters"
#define CTR_DICT_QUALIFIER_SET   "qualify:"
#define CTR_DICT_QUALIFIER       "qualifier"
#define CTR_DICT_NEW_SET         "new:"
#define CTR_DICT_HOUR            "hour"
#define CTR_DICT_HOUR_SET        "hour:"
#define CTR_DICT_MINUTE_SET      "minute:"
#define CTR_DICT_MINUTE          "minute"
#define CTR_DICT_SECOND_SET      "second:"
#define CTR_DICT_SECOND          "second"
#define CTR_DICT_DAY             "day"
#define CTR_DICT_DAY_SET         "day:"
#define CTR_DICT_WEEK            "week"
#define CTR_DICT_WEEK_SET        "week:"
#define CTR_DICT_MONTH           "month"
#define CTR_DICT_MONTH_SET       "month:"
#define CTR_DICT_YEAR            "year"
#define CTR_DICT_RAW             "plain"
#define CTR_DICT_YEAR_SET        "year:"
#define CTR_DICT_WEEK_DAY        "weekday"
#define CTR_DICT_YEAR_DAY        "day of the year"
#define CTR_DICT_ZONE            "zone"
#define CTR_DICT_ZONE_SET        "zone:"
#define CTR_DICT_ADD_SET         "add:"
#define CTR_DICT_SUBTRACT_SET    "subtract:"
#define CTR_DICT_MULTIPLIER_SET  "multiply by:"
#define CTR_DICT_DIVIDER_SET     "divide by:"
#define CTR_DICT_LAST            "last"
#define CTR_DICT_FIRST           "first"
#define CTR_DICT_SECOND_LAST     "penultimate"
#define CTR_DICT_FILL_WITH       "fill:with:"
#define CTR_DICT_SPLICE          "replace:length:with:"
#define CTR_DICT_VALUES          "values"
#define CTR_DICT_ENTRIES         "entries"
#define CTR_DICT_COMPARE_SET     "compare:"
#define CTR_DICT_HAS             "has:"
#define CTR_DICT_COPY            "copy"
#define CTR_DICT_CASE_DO         "case:do:"
#define CTR_DICT_STOP            "stop"
#define CTR_DICT_ASCII_UPPER_CASE                "capitals" 
#define CTR_DICT_ASCII_LOWER_CASE                "lowercase"
#define CTR_DICT_CONTAINS                        "contains:"
#define CTR_DICT_APPLY_TO_AND_AND                "apply:and:and:"
#define CTR_DICT_ENVIRONMENT_VARIABLE            "setting:"
#define CTR_DICT_SET_ENVIRONMENT_VARIABLE        "setting:value:" 
#define CTR_DICT_RESPOND_TO_AND_AND              "respond:and:and:"
#define CTR_DICT_RESPOND_TO_AND_AND_AND          "respond:and:and:and:"
#define CTR_DICT_CURRENT_TASK                    "this task"
#define CTR_DICT_NUM_DEC_SEP                     "."
#define CTR_DICT_NUM_THO_SEP                     ","
#define CTR_DICT_QUOT_OPEN                       "‘"
#define CTR_DICT_QUOT_CLOSE                      "’"
#define CTR_DICT_MESSAGE_CHAIN                   ","
#define CTR_DICT_ASSIGN                          "≔"
#define CTR_DICT_PAREN_OPEN                      "("
#define CTR_DICT_PAREN_CLOSE                     ")"
#define CTR_DICT_BLOCK_START                     "{"
#define CTR_DICT_BLOCK_END                       "}"
#define CTR_DICT_PARAMETER_PREFIX                ":"
#define CTR_DICT_RETURN                          "↲"
#define CTR_DICT_CODE                            "code"
#define CTR_DICT_PROCEDURE                       "procedure"
#define CTR_DICT_TOOBJECT        "object"
#define CTR_DICT_PATH_OBJECT "Path"
#define CTR_DICT_CMD_OBJECT  "Command"
#define CTR_DICT_RECURSIVE "recursive"
